@@ -1,13 +1,20 @@
 import rpyc
 import importlib
+import ida_auto
 import ida_loader
 import ida_pro
 import idc
 
 
 class HeadlessIda(rpyc.Service):
-    def on_disconnect(self, conn):
+    def __init__(self):
+        super().__init__()
+        ida_auto.auto_wait()
+
+    def on_connect(self, conn):
         ida_loader.set_database_flag(ida_loader.DBFL_KILL)
+
+    def on_disconnect(self, conn):
         ida_pro.qexit(0)
 
     def exposed_import_module(self, mod):
